@@ -142,6 +142,10 @@ WORKSPACE_DIAGNOSTIC      =
 'Diagnóstico de espaço de trabalho.'
 WORKSPACE_SKIP_HUGE_FILE  =
 'Por motivos de desempenho, a análise deste arquivo foi interrompida: {}'
+WORKSPACE_NOT_ALLOWED     = -- TODO: need translate!
+'Your workspace is set to `{}`. Lua language server refused to load this directory. Please check your configuration.[learn more here](https://github.com/sumneko/lua-language-server/wiki/Why-scanning-home-folder)'
+WORKSPACE_SCAN_TOO_MUCH   = -- TODO: need translate!
+'More than {} files have been scanned. The current scanned directory is `{}`. Please confirm whether the configuration is correct.'
 
 PARSER_CRASH            =
 'Parser quebrou! Últimas palavras: {}'
@@ -380,6 +384,8 @@ ACTION_DISABLE_DIAG_FILE=
 'Desativa diagnósticos nesta linha ({}).'
 ACTION_MARK_ASYNC       = -- TODO: need translate!
 'Mark current function as async.'
+ACTION_ADD_DICT         = -- TODO: need translate!
+'Add \'{}\' to workspace dict'
 
 COMMAND_DISABLE_DIAG       =
 'Desativar diagnósticos.'
@@ -399,6 +405,8 @@ COMMAND_JSON_TO_LUA        =
 'Converte de JSON para Lua.'
 COMMAND_JSON_TO_LUA_FAILED =
 'Converção de JSON para Lua falhou: {}.'
+COMMAND_ADD_DICT           = -- TODO: need translate!
+'Add Word to dictionary'
 
 COMPLETION_IMPORT_FROM           =
 'Importa de {}.'
